# avoiding version conflict, set version 2.0.0 for rhel8
%define upstream_vesion 2020-06-08

Name: rhel-system-roles-sap
Summary: System Roles to configure RHEL for running SAP NetWeaver- or SAP HANA-based products
Version: 2.0.0
Release: 3%{?dist}
License: GPLv3+
Url: https://github.com/berndfinger
Source0: https://github.com/berndfinger/sap-preconfigure/releases/download/2.0.0/sap-preconfigure.tar.gz
Source1: https://github.com/berndfinger/sap-hana-preconfigure/releases/download/2.0.0/sap-hana-preconfigure.tar.gz
Source2: https://github.com/berndfinger/sap-netweaver-preconfigure/releases/download/2.0.0/sap-netweaver-preconfigure.tar.gz
# git diff 2cbfd65fcc4988db4e9bc86bbf738217fe75bf49, fix 3 issues
#  - firewalld installation state detection not working
#  - File /etc/init.d/boot.local should have permissions of 0755 (configure-epb.yml)
#  - ask disable-firewall.yml in 2009879_7.yml also needs single step execution support
Patch0: sap-hana-preconfigure-2.0.0.patch
# for fixes for #78, #79, #81, #82, #94-#97, #99, #101-#102
Patch1: sap-hana-preconfigure-#95-#96-c11288a8354bf14f665e2ec92ff6b49f6828edfc.patch
Patch2: sap-hana-preconfigure-#94-#97-ecb7c33e9a8eddb633189d332683309d398fd54f.patch
Patch3: sap-hana-preconfigure-#99-d64615413b0bd7741bd6d8e06e5676be36a24c41.patch
Patch4: sap-hana-preconfigure-#101-063273dd09715cfcf69bcf3c1f4347225028ba70.patch
Patch5: sap-hana-preconfigure-#102-a622092d5063c2fb0d7996775521a52549e3a65a.patch
Patch6: sap-preconfigure-#78-db645e39a38070ac0b3fe9f2f447d60e6eedac4a.patch
Patch7: sap-preconfigure-#79-b056297b1e54662773d9b63850fdae34d2606fa1.patch
Patch8: sap-preconfigure-#81-6be65f40569044307bbf41038b766ff571a08025.patch
Patch9: sap-preconfigure-#82-70cd0f9f8b0f7de3e48c1af041a0d63443445052.patch

BuildArch: noarch
Requires: uuidd

%description
Collection of Ansible roles which configures a RHEL system according
to applicable SAP notes so that any SAP software can be installed.

%prep
%setup -q -T -c -n %{name}-%{version} -a 0 -a 1 -a 2
pushd sap-hana-preconfigure
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
popd
pushd sap-preconfigure
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
popd

# remove all SLES stuff
rm -rf sap-hana-preconfigure/tasks/SLES
rm -rf sap-hana-preconfigure/tasks/SLES15
rm -rf sap-hana-preconfigure/tasks/sapnote/1275776  # SLES - sapconf, saptune, etc
rm -rf sap-hana-preconfigure/tasks/sapnote/1944799* # SLES - HANA install and config guidelines
rm -rf sap-hana-preconfigure/tasks/sapnote/2578899  # SLES 15 - installation
rm -rf sap-hana-preconfigure/tasks/sapnote/2684254  # SLES 15 - OS settings for HANA
rm -f sap-hana-preconfigure/vars/SLES_15.yml

# remove all RHEL 6 stuff
rm -f sap-hana-preconfigure/tasks/sapnote/2013638.yml # RHEL 6.5 - OS settings
rm -f sap-hana-preconfigure/tasks/sapnote/2136965.yml # RHEL 6.6 - OS settings
rm -f sap-hana-preconfigure/tasks/sapnote/2247020.yml # RHEL 6.7 - OS settings
rm -f sap-hana-preconfigure/vars/RedHat_6.5.yml
rm -f sap-hana-preconfigure/vars/RedHat_6.6.yml
rm -f sap-hana-preconfigure/vars/RedHat_6.7.yml

%build

%install
mkdir -p $RPM_BUILD_ROOT%{_datadir}/ansible/roles \
         $RPM_BUILD_ROOT%{_pkgdocdir}/sap-hana-preconfigure \
         $RPM_BUILD_ROOT%{_pkgdocdir}/sap-preconfigure \
         $RPM_BUILD_ROOT%{_pkgdocdir}/sap-netweaver-preconfigure

# drop zero file
rm -f */.gitignore sap-hana-preconfigure/tasks/RedHat_6/recommendations.yml

cp -pR sap-hana-preconfigure sap-preconfigure sap-netweaver-preconfigure $RPM_BUILD_ROOT%{_datadir}/ansible/roles/
cp -p sap-hana-preconfigure/{README.md,LICENSE} $RPM_BUILD_ROOT%{_pkgdocdir}/sap-hana-preconfigure/
cp -p sap-preconfigure/{README.md,LICENSE} $RPM_BUILD_ROOT%{_pkgdocdir}/sap-preconfigure/
cp -p sap-netweaver-preconfigure/{README.md,LICENSE} $RPM_BUILD_ROOT%{_pkgdocdir}/sap-netweaver-preconfigure/

%files
%dir %{_pkgdocdir}
%dir %{_pkgdocdir}/sap-preconfigure
%dir %{_pkgdocdir}/sap-hana-preconfigure
%dir %{_pkgdocdir}/sap-netweaver-preconfigure
%dir %{_datadir}/ansible
%dir %{_datadir}/ansible/roles
%doc %{_pkgdocdir}/*/README.md
%license %{_pkgdocdir}/*/LICENSE
%{_datadir}/ansible/roles/*

%changelog
* Fri Jul 03 2020 Than Ngo <than@redhat.com> - 2.0.0-3
- Related: #1844190, drop 1944799.yml

* Mon Jun 29 2020 Than Ngo <than@redhat.com> - 2.0.0-2
- Related: #1844190, more fixes for #78, #79, #81, #82, #94-#97, #99, #101-#102

* Mon Jun 08 2020 Than Ngo <than@redhat.com> - 2.0.0-1
- Resolves: #1844190, rebase to 2.0.0

* Thu May 07 2020 Than Ngo <than@redhat.com> - 1.1.1-2
- Resolves: #1829495, fix summary

* Mon Oct 21 2019 Than Ngo <than@redhat.com> - 1.1.1-1
- rebase to 1.1.1
- always use ansible_hostname + ansible_domain instead of ansible_fqdn
- use {{ ansible_hostname }}.{{ ansible_domain }} instead of {{ ansible_fqdn }}
- added LC_ALL=C before commands for which the outputs are to be evaluated

* Thu Sep 12 2019 Than Ngo <than@redhat.com> - 1.1-1
- rebase to 1.1

* Fri Jun 28 2019 Than Ngo <than@redhat.com> - 1.0-1
- Initial release.
